@@ -2,7 +2,7 @@
 
 #######################################################################
 # dar - disk archive - a backup/restoration program
-# Copyright (C) 2002-2022 Denis Corbin
+# Copyright (C) 2002-2023 Denis Corbin
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -440,7 +440,7 @@ fi
 #  D2 -    operation with differential backup using delta signature
 #
 if echo $* | grep "D2" > /dev/null ; then
-GO "D2-1" 0 $ROUTINE_DEBUG $DAR -N -c $diff_delta -R $src -A $full_delta -B $OPT_NOSEQ
+GO "D2-1" 0 $ROUTINE_DEBUG $DAR -N -c $diff_delta -R $src -A $full_delta -B $OPT_NOSEQ --delta sig --delta-sig-min-size 1
 GO "D2-2" 0 $ROUTINE_DEBUG check_hash $hash $diff_delta.*.dar
 GO "D2-3" 0 $ROUTINE_DEBUG $DAR -N -l $diff_delta -B $OPT
 GO "D2-4" 0 $ROUTINE_DEBUG $DAR -N -t $diff_delta -B $OPT
@@ -452,24 +452,6 @@ GO "D2-8" 0 $ROUTINE_DEBUG my_diff $src $dst2
 rm -rf $dst2
 fi
 
-#
-# D3 -     operation with incremental backup using delta signature
-#
-
-if echo $* | grep "D3" > /dev/null ; then
-GO "D3-1" 0 $ROUTINE_DEBUG $DAR -N -c $diff_delta2 -R $src -A $catf_delta -B $OPT_NOSEQ --delta sig --delta-sig-min-size 1
-GO "D3-2" 0 $ROUTINE_DEBUG check_hash $hash $diff_delta2.*.dar
-GO "D3-3" 0 $ROUTINE_DEBUG $DAR -N -l $diff_delta2 -B $OPT
-GO "D3-4" 0 $ROUTINE_DEBUG $DAR -N -t $diff_delta2 -B $OPT
-GO "D3-5" 0 $ROUTINE_DEBUG $DAR -N -d $diff_delta2 -R $src -B $OPT
-mkdir $dst2
-GO "D3-6" 0 $ROUTINE_DEBUG $DAR -N -x $full -R $dst2 -B $OPT
-GO "D3-7" 0 $ROUTINE_DEBUG $DAR -N -x $diff_delta2 -R $dst2 -w -B $OPT
-GO "D3-8" 0 $ROUTINE_DEBUG my_diff $src $dst2
-rm -rf $dst2
-
-fi
-
 #
 #  E1 -   operation on an diff isolated catalogue alone
 #
